CY Celcat
This is a crate to interface with the CY Cergy Paris Univertity’s Celcat server through the API used by the official web app (not the admin API).
This is a crate to interface with the CY Cergy Paris Univertity’s Celcat server through the API used by the official web app (not the admin API).